Skip to main contentModule wire
Source - DataObjectFlags
- Flags in data object frame header.
- FrameFlags
- Common flags in every frame header’s
flags: u16 field. - FrameHeader
- The fixed 16-byte frame header.
- MessageFlags
- Flags in the message preamble indicating which optional frames are present.
- Postamble
- The fixed 24-byte message postamble (footer terminator).
- Preamble
- The fixed 24-byte message preamble.
- FrameType
- Frame type identifiers (uint16).
- DATA_OBJECT_FOOTER_SIZE
- Footer size of an
NTensorFrame (v3 type 9):
[cbor_offset u64][hash u64][ENDF 4] = 20 bytes. - END_MAGIC
- Message end magic: ASCII “39277777”
- FRAME_COMMON_FOOTER_SIZE
- Size of the common tail every v3 frame ends with:
[hash u64][ENDF 4] = 12 bytes. - FRAME_END
- Frame end marker: ASCII “ENDF”
- FRAME_HEADER_SIZE
- Frame header size: FR(2) + type(2) + version(2) + flags(2) + total_length(8) = 16
- FRAME_MAGIC
- Frame start marker: ASCII “FR”
- MAGIC
- Message start magic: ASCII “TENSOGRM”
- POSTAMBLE_SIZE
- Postamble size in v3: first_footer_offset(8) + total_length(8) + end_magic(8) = 24.
- PREAMBLE_SIZE
- Preamble size: magic(8) + version(2) + flags(2) + reserved(4) + total_length(8) = 24
- WIRE_VERSION
- Current wire-format version. See
plans/WIRE_FORMAT.md.
- footer_size_for
- Returns the size of the fixed footer for a given frame type.